OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "檔案分享",
    "Downloaded via public link" : "透過公開連結下載",
    "Downloaded by {email}" : "經由 {email} 下載",
    "{file} downloaded via public link" : "透過公開連結下載了 {file}",
    "{email} downloaded {file}" : "{email} 下載了 {file}",
    "Shared with group {group}" : "已與群組 {group} 分享",
    "Removed share for group {group}" : "移除了與群組 {group} 的分享",
    "{actor} shared with group {group}" : "{actor} 已與群組 {group} 分享",
    "{actor} removed share for group {group}" : "{actor} 移除了與群組 {group} 的分享",
    "Share for group {group} expired" : "群組 {group} 的分享已過期",
    "You shared {file} with group {group}" : "您已與 {file} 群組 {group} 分享",
    "You removed group {group} from {file}" : "您已將群組 {group} 從 {file} 移除",
    "{actor} shared {file} with group {group}" : "{actor} 已將 {file} 與群組 {group} 分享",
    "{actor} removed group {group} from {file}" : "{actor} 已將群組 {group} 從 {file} 移除",
    "Share for file {file} with group {group} expired" : "與群組 {group} 分享的檔案 {file} 已過期",
    "Shared as public link" : "已公開連結分享",
    "Removed public link" : "已移除公開連結",
    "Public link expired" : "公開連結已過期",
    "{actor} shared as public link" : "{actor} 已透過公開連結分享",
    "{actor} removed public link" : "{actor} 移除了公開連結分享",
    "Public link of {actor} expired" : "{actor} 的公開連結過期了",
    "You shared {file} as public link" : "您已透過公開連結分享 {file}",
    "You removed public link for {file}" : "您移除了 {file} 的公開分享連結",
    "Public link expired for {file}" : "{file} 的公開連結已過期",
    "{actor} shared {file} as public link" : "{actor} 已透過公開連結分享 {file}",
    "{actor} removed public link for {file}" : "{actor} 移除了 {file} 的公開連結分享",
    "Public link of {actor} for {file} expired" : "{actor} 公開分享 {file} 的連結過期了",
    "{user} accepted the remote share" : "{user} 接受了遠端分享",
    "{user} declined the remote share" : "{user} 拒絕了遠端分享",
    "You received a new remote share {file} from {user}" : "您收到了來自 {user} 的遠端分享 {file}",
    "{user} accepted the remote share of {file}" : "{user} 接受了檔案 {file} 的遠端分享",
    "{user} declined the remote share of {file}" : "{user} 拒絕了檔案 {file} 的遠端分享",
    "{user} unshared {file} from you" : "{user} 取消了與您分享的檔案 {file}",
    "Shared with {user}" : "已與 {user} 分享",
    "Removed share for {user}" : "移除了與 {user} 的分享",
    "You removed yourself" : "您移除了自己",
    "{actor} removed themselves" : "{actor} 已將自己移除",
    "{actor} shared with {user}" : "{actor} 已與 {user} 分享",
    "{actor} removed share for {user}" : "{actor} 移除了與 {user} 的分享",
    "Shared by {actor}" : "由 {actor} 分享",
    "{actor} removed share" : "{actor} 移除了分享",
    "Share for {user} expired" : "{user} 的分享已過期",
    "Share expired" : "分享已過期",
    "You shared {file} with {user}" : "您與 {user} 分享了 {file}",
    "You removed {user} from {file}" : "您已將 {user} 從 {file} 移除",
    "You removed yourself from {file}" : "您已將自己從 {file} 移除",
    "{actor} removed themselves from {file}" : "{actor} 從 {file} 移除了自己",
    "{actor} shared {file} with {user}" : "{actor} 與 {user} 分享了 {file}",
    "{actor} removed {user} from {file}" : "{actor} 從 {file} 移除了 {user}",
    "{actor} shared {file} with you" : "{actor} 與您分享了 {file}",
    "{actor} removed you from the share named {file}" : "{actor} 已將您從名為 {file} 的分享中移除",
    "Share for file {file} with {user} expired" : "與 {user} 分享的檔案 {file} 已過期",
    "Share for file {file} expired" : "檔案 {file} 的分享已過期",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "透過電子郵件或公開連結分享的檔案或資料夾<strong>已下載</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "檔案已<strong>上傳</strong>至透過電子郵件或公開連結分享的資料夾",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>其他伺服器</strong>分享的檔案或資料夾",
    "Sharing" : "分享",
    "A file or folder has been <strong>shared</strong>" : "檔案或資料夾已<strong>分享</strong>",
    "Shared link" : "已分享的連結",
    "Wrong share ID, share does not exist" : "錯誤的分享 ID，分享不存在",
    "Could not delete share" : "無法刪除分享",
    "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
    "Wrong path, file/folder does not exist" : "錯誤的路徑，該檔案或資料夾不存在",
    "Could not create share" : "無法建立分享",
    "Please specify a valid account to share with" : "請指定要分享的有效帳號",
    "Group sharing is disabled by the administrator" : "群組分享已被管理員停用",
    "Please specify a valid group" : "請指定有效的群組",
    "Public link sharing is disabled by the administrator" : "公開連結分享已被管理員停用",
    "Please specify a valid email address" : "請指定有效的電子郵件地址",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享 %s 失敗",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "後端不允許 %2$s 類型的分享，因此 %1$s 分享失敗",
    "Please specify a valid federated account ID" : "請指定有效的聯盟帳號 ID",
    "Please specify a valid federated group ID" : "請指定有效的聯邦群組 ID",
    "You cannot share to a Team if the app is not enabled" : "因為應用程式未啟用，所以您無法分享至團隊",
    "Please specify a valid team" : "請指定有效的團隊",
    "Sharing %s failed because the back end does not support room shares" : "後端不支援聊天室分享，%s 分享失敗",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "後端不支援 ScienceMesh 分享，%s 分享失敗",
    "Unknown share type" : "未知的分享類型",
    "Not a directory" : "不是目錄",
    "Could not lock node" : "無法鎖定節點",
    "Public upload is only possible for publicly shared folders" : "只有公開分享的資料夾可以接受公開上傳",
    "Share must at least have READ or CREATE permissions" : "分享必須至少具備 READ 或 CREATE 權能",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "若設定了 UPDATE 或 DELETE 權能，則分享必須具備 READ 權能",
    "Public upload disabled by the administrator" : "公開上傳已被管理員停用",
    "Could not lock path" : "無法鎖定路徑",
    "no sharing rights on this item" : "沒有此項目的分享權限",
    "You are not allowed to edit incoming shares" : "您無權編輯收到的分享",
    "Wrong or no update parameter given" : "更新參數不正確或未提供",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "「透過 Nextcloud Talk 傳送密碼」分享檔案或資料夾失敗，因為未啟用 Nextcloud Talk。",
    "Custom share link tokens have been disabled by the administrator" : "自訂分享連結權杖已被管理員停用",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "權杖必須至少包含 1 個字元，且只能包含字母、數字或連字符。",
    "Invalid date. Format must be YYYY-MM-DD" : "無效的日期。格式必須為 YYYY-MM-DD",
    "No sharing rights on this item" : "沒有此項目的分享權限",
    "Invalid share attributes provided: \"%s\"" : "提供的分享屬性無效：「%s」",
    "You are not allowed to send mail notifications" : "您無權寄送郵件通知",
    "No mail notification configured for this share type" : "此分享類型並未設定郵件通知",
    "Wrong password" : "密碼錯誤",
    "Error while sending mail notification" : "寄送郵件通知時發生錯誤",
    "Failed to generate a unique token" : "產生獨一無二的權杖失敗",
    "This share does not exist or is no longer available" : "此分享不存在或是不再提供",
    "shared by %s" : "由 %s 分享",
    "Download" : "下載",
    "Add to your %s" : "新增至您的 %s",
    "Direct link" : "直接連結",
    "Share API is disabled" : "分享 API 已停用",
    "File sharing" : "檔案分享",
    "Share will expire tomorrow" : "分享將於明天到期",
    "Your share of {node} will expire tomorrow" : "您 {node} 的分享將於明天到期",
    "You received {share} as a share by {user}" : "您收到了 {user} 分享的 {share}",
    "You received {share} to group {group} as a share by {user}" : "您收到了 {user} 與 {group} 群組分享的 {share}",
    "Accept" : "接受",
    "Decline" : "回絕",
    "Remember to upload the files to %s" : "記得將檔案上傳至 %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "我們謹提醒您，您尚未將任何檔案上傳到共用資料夾。",
    "Open \"%s\"" : "開啟「%s」",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "此應用程式讓使用者可以在 Nextcloud 中分享檔案。若啟用，管理員可以選擇哪些群組可以分享檔案。應用程式使用者可以與其他在 Nextcloud 中的使用者與群組分享檔案與資料夾。此外，如果管理員啟用了分享連結的功能，則可以使用外部連結與 Nextcloud 之外的使用者分享檔案。管理員也可以啟用密碼、到期日以及啟用透過分享連結的伺服器到伺服器分享，並可從行動裝置分享。\n將此功能關閉會移除伺服器上、同步客戶端與行動應用程式所有的分享收件者，以及檔案與資料夾。更多資訊請見 Nextcloud 文件。",
    "People" : "人物",
    "Filter accounts" : "篩選帳號",
    "The request will expire on {date} at midnight and will be password protected." : "請求將於{date}午夜過期，並將受到密碼保護。",
    "The request will expire on {date} at midnight." : "請求將於{date}午夜過期。",
    "The request will be password protected." : "請求將受到密碼保護。",
    "When should the request expire?" : "請求應在何時過期？",
    "Set a submission expiration date" : "設定遞交截止日期",
    "Expiration date" : "到期日",
    "Select a date" : "選取日期",
    "Your administrator has enforced a {count} days expiration policy." : "您的管理員已強制執行{count}天的逾期政策。",
    "What password should be used for the request?" : "請求應該使用什麼密碼？",
    "Set a password" : "設定密碼",
    "Password" : "密碼",
    "Enter a valid password" : "輸入有效密碼",
    "Generate a new password" : "產生新密碼",
    "Your administrator has enforced a password protection." : "您的管理員已強制設定密碼保護。",
    "Automatically copying failed, please copy the share link manually" : "自動複製失敗，請手動複製分享連結",
    "Link copied" : "連結已複製",
    "Email already added" : "已新增電子郵件",
    "Invalid email address" : "無效的電子郵件地址",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["以下電子郵件地址無效：{emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["已新增 {count} 個電子郵件地址"],
    "_{count} email address added_::_{count} email addresses added_" : ["新增了 {count} 個電子郵件地址"],
    "You can now share the link below to allow people to upload files to your directory." : "您現在可以分享下面的連結，讓其他人將檔案上傳到您的目錄中。",
    "Share link" : "分享連結",
    "Copy" : "複製",
    "Send link via email" : "透過 email 寄送連結",
    "Enter an email address or paste a list" : "請輸入電子郵件地址或貼上清單",
    "Remove email" : "移除電子郵件",
    "Select a destination" : "選取目的地",
    "Select" : "選取",
    "What are you requesting?" : "您正在請求什麼？",
    "Request subject" : "請求主旨",
    "Birthday party photos, History assignment…" : "生日派對照片、歷史作業……",
    "Where should these files go?" : "這些檔案應該放在哪裡？",
    "Upload destination" : "上傳目的地",
    "Revert to default" : "還原回預設值",
    "The uploaded files are visible only to you unless you choose to share them." : "上傳的檔案僅對您可見，除非您選擇分享它們。",
    "Add a note" : "新增備註",
    "Note for recipient" : "給收件者的備註",
    "Add a note to help people understand what you are requesting." : "新增備註以協助他人了解您的請求。",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "您可以新增連結、日期或任何資訊，以協助收件者了解您的請求。",
    "Close" : "關閉",
    "_Send email and close_::_Send {count} emails and close_" : ["寄送 {count} 封電子郵件並關閉"],
    "Please select a folder, you cannot share the root directory." : "請選取資料夾，您無法分享根目錄。",
    "File request created" : "已建立檔案請求",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["已建立檔案請求，已寄送 {count} 封電子郵件"],
    "Error creating the share: {errorMessage}" : "建立分享時發生錯誤：{errorMessage}",
    "Error creating the share" : "建立分享時發生錯誤",
    "Error sending emails: {errorMessage}" : "寄送電子郵件時發生錯誤：{errorMessage}",
    "Error sending emails" : "寄送電子郵件時發生錯誤",
    "Create a file request" : "建立檔案請求",
    "Collect files from others even if they do not have an account." : "即使對方沒有帳號，也可以蒐集檔案。",
    "To ensure you can receive files, verify you have enough storage available." : "為了確保您能接收檔案，請確認您有足夠的可用儲存空間。",
    "File request" : "檔案請求",
    "Previous step" : "上一步",
    "Cancel" : "取消",
    "Cancel the file request creation" : "取消建立檔案請求",
    "Close without sending emails" : "關閉而不寄送電子郵件",
    "Continue" : "繼續",
    "Error while toggling options" : "切換選項時發生錯誤",
    "Accept shares from other accounts and groups by default" : "預設接受其他帳號與群組的分享",
    "Choose a default folder for accepted shares" : "為接受的分享選擇預設資料夾",
    "Invalid path selected" : "選取的路徑無效",
    "Unknown error" : "未知的錯誤",
    "Set default folder for accepted shares" : "為接受的分享設定預設資料夾",
    "Reset" : "重設",
    "Reset folder to system default" : "將資料夾重設回系統預設",
    "Share expiration: {date}" : "分享到期日：{date}",
    "Share Expiration" : "分享過期",
    "group" : "群組",
    "conversation" : "對話",
    "remote" : "遠端",
    "remote group" : "遠端群組",
    "guest" : "訪客",
    "by {initiator}" : "由 {initiator}",
    "Shared with the group {user} by {owner}" : "{owner} 與群組 {user} 分享",
    "Shared with the conversation {user} by {owner}" : "{owner} 與對話 {user} 分享",
    "Shared with {user} by {owner}" : "{owner} 與 {user} 分享",
    "Open Sharing Details" : "開啟分享詳細資訊",
    "Added by {initiator}" : "{initiator} 新增",
    "Via “{folder}”" : "透過「{folder}」",
    "Unshare" : "取消分享",
    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
    "Copy internal link" : "複製內部連結",
    "For people who already have access" : "對於已有存取權限的人",
    "Internal link" : "內部連結",
    "{shareWith} by {initiator}" : "{initiator} {shareWith}",
    "Shared via link by {initiator}" : "{initiator} 透過連結分享",
    "File request ({label})" : "檔案請求（{label}）",
    "Mail share ({label})" : "經郵件分享 ({label})",
    "Share link ({label})" : "分享連結 ({label})",
    "Mail share" : "郵件分享",
    "Share link ({index})" : "分享連結 ({index})",
    "Create public link" : "建立公開連結",
    "Actions for \"{title}\"" : "「{title}」的動作",
    "Copy public link of \"{title}\"" : "複製「{title}」的公開連結",
    "Error, please enter proper password and/or expiration date" : "錯誤，請輸入適當的密碼及/或到期日",
    "Link share created" : "建立了連結分享",
    "Error while creating the share" : "建立分享時發生錯誤",
    "Your browser does not support copying, please copy the link manually:" : "您的瀏覽器不支援複製功能，請手動複製連結：",
    "Successfully copied public link" : "複製公開連結成功",
    "Please enter the following required information before creating the share" : "在建立分享前，請輸入以下的必要資訊",
    "Password protection (enforced)" : "密碼保護（強制）",
    "Password protection" : "密碼保護",
    "Enter a password" : "請輸入密碼",
    "Enable link expiration (enforced)" : "啟用連結過期（強制執行）",
    "Enable link expiration" : "啟用連結過期",
    "Enter expiration date (enforced)" : "輸入到期日（強制執行）",
    "Enter expiration date" : "輸入到期日",
    "Create share" : "建立分享",
    "Customize link" : "自訂連結",
    "Generate QR code" : "產生 QR code",
    "Add another link" : "新增其他連結",
    "Create a new share link" : "建立新分享連結",
    "Quick share options, the current selected is \"{selectedOption}\"" : "快速分享選項，目前已選取「{selectedOption}」",
    "View only" : "僅供檢視",
    "Can edit" : "可以編輯",
    "Custom permissions" : "自訂權限",
    "Resharing is not allowed" : "不允許轉發分享",
    "Name or email …" : "名稱或電子郵件 ……",
    "Name, email, or Federated Cloud ID …" : "名稱、電子郵件或雲端聯邦 ID ……",
    "Searching …" : "正在搜尋 …",
    "No elements found." : "找不到元素。",
    "Search everywhere" : "到處搜尋",
    "Guest" : "訪客",
    "Group" : "群組",
    "Email" : "電子郵件",
    "Team" : "團隊",
    "Talk conversation" : "Talk 對話",
    "Deck board" : "看板佈告欄",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "於 {server}",
    "Enter external recipients" : "輸入外部接收者",
    "Search for internal recipients" : "搜尋內部接收者",
    "Note from" : "備註來自",
    "Note:" : "備註：",
    "File drop" : "檔案投遞",
    "Upload files to {foldername}." : "上傳檔案至 {foldername}。",
    "By uploading files, you agree to the terms of service." : "上傳檔案即表示您同意服務條款。",
    "Successfully uploaded files" : "已成功上傳檔案",
    "View terms of service" : "檢視服務條款",
    "Terms of service" : "服務條款",
    "Share with {user}" : "與 {user} 分享",
    "Share with email {email}" : "與電子郵件 {email} 分享",
    "Share with group" : "與群組分享",
    "Share in conversation" : "在對話中分享",
    "Share with {user} on remote server {server}" : "與遠端伺服器 {server} 上的 {user} 分享",
    "Share with remote group" : "與遠端群組分享",
    "Share with guest" : "與訪客分享",
    "Update share" : "更新分享",
    "Save share" : "儲存分享",
    "Read" : "讀取",
    "Create" : "建立",
    "Edit" : "編輯",
    "Share" : "分享",
    "Delete" : "刪除",
    "Password field cannot be empty" : "密碼欄位不能為空",
    "Replace current password" : "取代目前密碼",
    "Failed to generate a new token" : "產生新權杖失敗",
    "Allow upload and editing" : "允許上傳及編輯",
    "Allow editing" : "允許編輯",
    "Upload only" : "僅供上傳",
    "Advanced settings" : "進階設定",
    "Share label" : "分享標籤",
    "Share link token" : "分享連結權杖",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "將公開分享連結權杖設定為容易記住的權杖，或產生新的權杖。不建議對包含敏感資訊的分享使用可猜測的權杖。",
    "Generating…" : "正在產生……",
    "Generate new token" : "產生新權杖",
    "Set password" : "設定密碼",
    "Password expires {passwordExpirationTime}" : "密碼於 {passwordExpirationTime} 到期",
    "Password expired" : "密碼已過期",
    "Video verification" : "視訊驗證",
    "Expiration date (enforced)" : "到期日（強制）",
    "Set expiration date" : "設定到期日",
    "Hide download" : "隱藏下載",
    "Allow download and sync" : "允許下載與同步",
    "Note to recipient" : "給接收者的備註",
    "Enter a note for the share recipient" : "輸入給分享接收者的備註",
    "Show files in grid view" : "以網格檢視顯示檔案",
    "Delete share" : "刪除分享",
    "Others with access" : "擁有存取權的其他人",
    "No other accounts with access found" : "找不到其他有存取權的使用者",
    "Toggle list of others with access to this directory" : "切換有權存取此目錄的其他人列表",
    "Toggle list of others with access to this file" : "切換有權存取此檔案的其他人列表",
    "Unable to fetch inherited shares" : "無法擷取繼承的分享",
    "Link shares" : "連結分享",
    "Shares" : "分享",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "在您的組織內部分享檔案。已經可以檢視檔案的收件者也可以使用此連結以方便存取。",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "透過公開連結與電子郵件地址與組織外的其他人分享檔案。您也可以使用其他站台上的聯邦雲端 ID 將檔案分享至 {productName} 帳號。",
    "Shares from apps or other sources which are not included in internal or external shares." : "來自應用程式或其他來源的分享，不包括在內部或外部分享中。",
    "Type names, teams, federated cloud IDs" : "輸入名稱、團隊、聯邦雲端 ID",
    "Type names or teams" : "輸入名稱或團隊",
    "Type a federated cloud ID" : "輸入聯邦雲端 ID",
    "Type an email" : "輸入電子郵件",
    "Type an email or federated cloud ID" : "輸入電子郵件或聯邦雲端 ID",
    "Unable to load the shares list" : "無法載入分享列表",
    "Expires {relativetime}" : "過期於 {relativetime}",
    "this share just expired." : "此分享剛過期。",
    "Shared with you by {owner}" : "{owner} 已與您分享",
    "Internal shares" : "內部分享",
    "Internal shares explanation" : "內部分享說明",
    "External shares" : "外部分享",
    "External shares explanation" : "外部分享說明",
    "Additional shares" : "額外分享",
    "Additional shares explanation" : "額外分享說明",
    "Link to a file" : "檔案連結",
    "_Accept share_::_Accept shares_" : ["接受分享"],
    "Open in Files" : "以「檔案」開啟",
    "_Reject share_::_Reject shares_" : ["拒絕分享"],
    "_Restore share_::_Restore shares_" : ["還原分享"],
    "Shared" : "已分享",
    "Shared by {ownerDisplayName}" : "{ownerDisplayName} 分享",
    "Shared multiple times with different people" : "與不同的人多次分享",
    "Sharing options" : "分享選項",
    "Shared with others" : "與其他人分享",
    "You do not have enough permissions to share this file." : "您無權分享此檔案。",
    "Create file request" : "建立檔案請求",
    "Upload files to {foldername}" : "上傳檔案至 {foldername}",
    "Public file share" : "公開連結分享",
    "Publicly shared file." : "公開分享的檔案。",
    "No file" : "無檔案",
    "The file shared with you will show up here" : "與您分享的檔案將會在此顯示",
    "Public share" : "公開分享",
    "Publicly shared files." : "公開分享的檔案。",
    "No files" : "沒有檔案",
    "Files and folders shared with you will show up here" : "與您分享的檔案與資料夾將會在此顯示",
    "Overview of shared files." : "已分享檔案的概覽。",
    "No shares" : "無分享",
    "Files and folders you shared or have been shared with you will show up here" : "您分享的或與您分享的檔案與資料夾將顯示在此處",
    "Shared with you" : "與您分享",
    "List of files that are shared with you." : "與您分享的檔案清單。",
    "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
    "Files and folders others shared with you will show up here" : "與您分享的檔案與資料夾將會顯示在此處",
    "List of files that you shared with others." : "您與其他人分享的檔案清單。",
    "Nothing shared yet" : "目前沒有分享內容",
    "Files and folders you shared will show up here" : "您分享的檔案與資料夾將會顯示在此處",
    "Shared by link" : "透過連結分享",
    "List of files that are shared by link." : "透過連結分享的檔案清單。",
    "No shared links" : "沒有分享的連結",
    "Files and folders you shared by link will show up here" : "您分享的檔案與資料夾連結將會顯示在此處",
    "File requests" : "檔案請求",
    "List of file requests." : "檔案請求清單",
    "No file requests" : "沒有檔案請求",
    "File requests you have created will show up here" : "您建立的檔案請求將會顯示在此處",
    "Deleted shares" : "刪除的分享",
    "List of shares you left." : "您離開的分享清單。",
    "No deleted shares" : "沒有刪除的分享",
    "Shares you have left will show up here" : "您離開的分享將會顯示在此處",
    "Pending shares" : "待處理的分享",
    "List of unapproved shares." : "未批准的分享清單。",
    "No pending shares" : "沒有待處理的分享",
    "Shares you have received but not approved will show up here" : "您收到但尚未核准的分享將會在此顯示",
    "Error deleting the share: {errorMessage}" : "刪除分享時發生錯誤：{errorMessage}",
    "Error deleting the share" : "刪除分享時發生錯誤",
    "Error updating the share: {errorMessage}" : "更新分享時發生錯誤：{errorMessage}",
    "Error updating the share" : "更新分享時發生錯誤",
    "File \"{path}\" has been unshared" : "檔案「{path}」已取消分享",
    "Folder \"{path}\" has been unshared" : "資料夾「{path}」已取消分享",
    "Could not update share" : "無法更新分享",
    "Share saved" : "已儲存分享",
    "Share expiry date saved" : "已儲存分享過期日期",
    "Share hide-download state saved" : "已儲存分享隱藏下載狀態",
    "Share label saved" : "分享標籤已儲存",
    "Share note for recipient saved" : "已儲存給收件者的分享備註",
    "Share password saved" : "分享密碼已儲存",
    "Share permissions saved" : "已儲存分享權限",
    "To upload files to {folder}, you need to provide your name first." : "要上傳檔案至 {folder}，您必須先提供您的名稱。",
    "Upload files to {folder}" : "上傳檔案到 {folder}",
    "Please confirm your name to upload files to {folder}" : "請確認您的名稱以上傳檔案至 {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} 與您分享了一個資料夾。",
    "Names must not be empty." : "名稱不能為空。",
    "Names must not start with a dot." : "名稱不能以點開頭。",
    "\"{char}\" is not allowed inside a name." : "「{char}」不能在名稱內使用。",
    "\"{segment}\" is a reserved name and not allowed." : "「{segment}」為保留名稱且不允許使用。",
    "\"{extension}\" is not an allowed name." : "「{extension}」不是允許的名稱。",
    "Names must not end with \"{extension}\"." : "名稱不能以「{extension}」結尾。",
    "Invalid name." : "無效的名稱。",
    "Password created successfully" : "成功建立密碼",
    "Error generating password from password policy" : "從密碼策略產生密碼時發生錯誤",
    "Shared with you and the group {group} by {owner}" : "{owner} 與您和群組 {group} 分享",
    "Shared with you and {circle} by {owner}" : "{owner} 與您和 {circle} 分享",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 與您和 {conversation} 對話分享",
    "Shared with you in a conversation by {owner}" : "{owner} 在對話中與您分享",
    "Share not found" : "找不到分享",
    "Back to %s" : "回到 %s",
    "Add to your Nextcloud" : "新增到您的 Nextcloud",
    "Link copied to clipboard" : "已複製連結至剪貼簿",
    "Copy to clipboard" : "複製到剪貼簿",
    "Copy internal link to clipboard" : "複製內部連結至剪貼簿",
    "Only works for people with access to this folder" : "只對可以存取此資料夾的使用者生效",
    "Only works for people with access to this file" : "只對可以存取此檔案的使用者生效",
    "Copy public link of \"{title}\" to clipboard" : "將「{title}」的公開連結複製到剪貼簿",
    "Name or email …" : "名稱或電子郵件…",
    "Name, email, or Federated Cloud ID …" : "名稱、電子郵件或雲端聯邦 ID…",
    "Searching …" : "正在搜尋…",
    "Search globally" : "全域搜尋",
    "Submit name" : "遞交名稱",
    "To upload files, you need to provide your name first." : "要上傳檔案，您必須先提供您的名字。",
    "Name" : "名稱",
    "Enter your name" : "輸入您的名稱",
    "Share with {userName}" : "與 {userName} 分享",
    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "使用此方法與組織內的個人或團隊分享檔案。如果收件者已經可以存取分享但找不到，您可以將內部分享連結傳送給他們，以方便存取。",
    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "使用此方法與組織外的個人或組織分享檔案。檔案與資料夾可以透過公開的分享連結與電子郵件地址來分享。您也可以使用其他 Nextcloud 帳號的聯邦雲端 ID，將檔案分享給託管在不同站台上的其他 Nextcloud 帳號。",
    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "不屬於內部或外部分享的分享。這可能是來自應用程式或其他來源的分享。",
    "Share with accounts, teams, federated cloud id" : "與帳號、團隊、聯邦雲端ID 分享",
    "Share with accounts and teams" : "與帳號及團隊分享",
    "Federated cloud ID" : "聯邦雲端 ID",
    "Email, federated cloud id" : "電子郵件、聯邦雲端 ID",
    "Show sharing options" : "顯示分享選項",
    "Filename must not be empty." : "檔案名稱不能為空。",
    "Shared by" : "分享者",
    "Shared with" : "分享給",
    "Share note" : "分享備註",
    "Show list view" : "顯示清單檢視",
    "Show grid view" : "顯示格狀檢視",
    "Upload files to %s" : "上傳檔案到 %s",
    "%s shared a folder with you." : "%s 與您分享了一個資料夾。",
    "Note" : "備註",
    "Select or drop files" : "選取或拖曳檔案",
    "Uploading files" : "正在上傳檔案",
    "Uploaded files:" : "已上傳的檔案：",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "上傳檔案即表示您同意 %1$s服務條款%2$s。"
},
"nplurals=1; plural=0;");
